@@ -5,7 +5,7 @@ import sys
 from pyface.qt import QtCore, QtGui
 
 # Enthought library imports.
-from traits.api import DelegatesTo, Instance, implements, on_trait_change
+from traits.api import DelegatesTo, Instance, on_trait_change, provides
 
 # Local imports.
 from pyface.tasks.i_advanced_editor_area_pane import IAdvancedEditorAreaPane
@@ -19,13 +19,13 @@ from util import set_focus
 # 'AdvancedEditorAreaPane' class.
 ###############################################################################
 
+@provides(IAdvancedEditorAreaPane)
 class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
     """ The toolkit-specific implementation of an AdvancedEditorAreaPane.
 
     See the IAdvancedEditorAreaPane interface for API documentation.
     """
 
-    implements(IAdvancedEditorAreaPane)
 
     #### Private interface ####################################################
 
@@ -109,6 +109,8 @@ class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
         self.editors.remove(editor)
         self.control.remove_editor_widget(editor_widget)
         editor.editor_area = None
+        if not self.editors:
+            self.active_editor = None
 
     ###########################################################################
     # 'IAdvancedEditorAreaPane' interface.
@@ -540,6 +542,13 @@ class EditorWidget(QtGui.QDockWidget):
         self.setWidget(editor.control)
         self.update_title()
 
+        # Update the minimum size.
+        contents_minsize = editor.control.minimumSize()
+        style = self.style()
+        contents_minsize.setHeight(contents_minsize.height()
+            + style.pixelMetric(style.PM_DockWidgetHandleExtent))
+        self.setMinimumSize(contents_minsize)
+
         self.dockLocationChanged.connect(self.update_title_bar)
         self.visibilityChanged.connect(self.update_title_bar)
 
