@@ -4,7 +4,7 @@ import sys
 # Enthought library imports.
 from pyface.tasks.i_editor_area_pane import IEditorAreaPane, \
     MEditorAreaPane
-from traits.api import implements, on_trait_change
+from traits.api import on_trait_change, provides
 
 # System library imports.
 from pyface.qt import QtCore, QtGui
@@ -17,13 +17,13 @@ from util import set_focus
 # 'EditorAreaPane' class.
 ###############################################################################
 
+@provides(IEditorAreaPane)
 class EditorAreaPane(TaskPane, MEditorAreaPane):
     """ The toolkit-specific implementation of a EditorAreaPane.
 
     See the IEditorAreaPane interface for API documentation.
     """
 
-    implements(IEditorAreaPane)
 
     ###########################################################################
     # 'TaskPane' interface.
@@ -111,6 +111,8 @@ class EditorAreaPane(TaskPane, MEditorAreaPane):
         editor.destroy()
         editor.editor_area = None
         self._update_tab_bar()
+        if not self.editors:
+            self.active_editor = None
 
     ###########################################################################
     # Protected interface.
