@@ -285,7 +285,13 @@ class MainWindowLayout(HasTraits):
         QWIDGETSIZE_MAX = (1 << 24) - 1 # Not exposed by Qt bindings.
         for child in self.control.children():
             if isinstance(child, QtGui.QDockWidget):
-                child.widget().setFixedSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX)
+                child.widget().setMaximumSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX)
+                child.widget().setMinimumSize(0, 0)
+                # QDockWidget somehow manages to set its own
+                # min/max sizes and hence that too needs to be reset.
+                child.setMaximumSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX)
+                child.setMinimumSize(0, 0)
+
 
 
 class MainWindowLayoutError(ValueError):
